function [Y,Z] = genHLNsamples(numdocs, numdraws,mu,cov)

% GENHLNSAMPLES
%
% function [Y,Z] = genHLNsamples(numdocs, numdraws,mu,cov)
%
% Generates numdocs "documents" each with numdraws samples
% from the Hierarchical Logistic Normal Distribution with 
% parameters mu,cov.
% 
% input:
%   numdocs, numdraws both positive integers
%   mu is a (k-1)x1 vector, cov is a (k-1)x(k-1) covariance matrix
% output:
%   Y is numdocsxk histogram of draws whose rows sum to numdraws
%   Z is kxN matrix of draws from the Logistic Normal
% 
% Authors: Jonathan Huang       (jch1 at cs.cmu.edu)
%          Tomasz Malisiewicz  (tomasz at cmu.edu)

Z = genSamps(numdocs,mu,cov);
Y = zeros(length(mu)+1,numdocs);
for i=1:size(Y,2)
    Y(:,i) = sample_hist(Z(:,i),numdraws);
end
Y = Y';