function plotLNlevelsets(mu,cov,cbaroption)

% PLOGLNLEVELSETS
%
% function plotLNlevelsets(mu,cov,cbaroption)
%
% input:
%   Plots equal-probability curves from a Logistic Normal with parameters 
% mu,cov where:
% mu is a 2x1 vector
% cov is a 2x2 covariance matrix.
% If cbaroption is nonzero, then a colorbar will be plotted
% 
% Example: plotLNlevelsets([1;0],eye(2),1);
% 
% Authors: Jonathan Huang       (jch1 at cs.cmu.edu)
%          Tomasz Malisiewicz  (tomasz at cmu.edu)

res=200;
map=zeros(res^2/2,1);
tris = zeros(res^2/2,3);
tris2d = zeros(res^2/2,2);
indices = zeros(res^2,3);
p=[0 0 1];
u = 0;
v = 1;
counter=0;
for i=1:res
    for j=1:res-i
        counter=counter+1;
        u = i/res; v = j/res;
        p = max([u v 1-u-v],1e-10);
        tris2d(counter,:)=[u v];
        tris(counter,:)=p;
        w = log(p)'-log(p(end));
        map(counter) = 1/(prod(p))*exp(-.5*(w(1:end-1)-mu)'*cov^(-1)*(w(1:end-1)-mu));
        if ~isfinite(map(counter))
            map(counter) = 0;
        end
    end
end
tris=tris(1:counter,:);
tris2d=tris2d(1:counter,:);
D=delaunay(tris2d(:,1),tris2d(:,2));
map=(255*(map(1:counter)/max(map)));
colormap(jet)
trisurf(D,tris(:,1),tris(:,2),tris(:,3),'LineStyle','none', ...
        'Cdata',map,'FaceColor','interp')

campos([2 2 2]);
camtarget([0 0 0]);

axis off
box off
grid off
alpha(.5);

if exist('cbaroption') 
    if cbaroption ~= 0 
        hcb=colorbar('South','XTick',[1 64 128 192 255],'XTickLabel',{'0.0','0.25','0.5','0.75','1.0'});
        set(hcb,'XTickMode','manual');
    end 
end