function plotlogisticnormal(mu,cov,mcolor)

% PLOGLOGISTICNORMAL
%
% function plotlogisticnormal(mu,cov,mcolor)
%
% input:
%   Draws samples from a Logistic Normal with parameters mu,cov
% and plots these samples as mcolor points on a 2-simplex.
% mu is a 2x1 vector
% cov is a 2x2 covariance matrix.
% 
% Example: plotlogisticnormal([1;0],eye(2),[1 0 0]);
% 
% Authors: Jonathan Huang       (jch1 at cs.cmu.edu)
%          Tomasz Malisiewicz  (tomasz at cmu.edu)

X = genSamps(50000,mu,cov)';

for k=1:1  
res=50;
map=zeros(res^2/2,1);
tris = zeros(res^2/2,3);
tris2d = zeros(res^2/2,2);
indices = zeros(res^2,3);
p=[0 0 1];
u = 0;
v = 1;
counter=0;
for i=1:res
    for j=1:res-i
        counter=counter+1;
        u = i/res;
        v = j/res;
        p = [u v 1-u-v];
        tris2d(counter,:)=[u v];
        tris(counter,:)=p;
        map(counter) = 0.01;
    end
end
tris=tris(1:counter,:);
tris2d=tris2d(1:counter,:);
D=delaunay(tris2d(:,1),tris2d(:,2));
map=(255*(map(1:counter)/max(map)))*0;

axis off
colormap(cool)
trisurf(D,tris(:,1),tris(:,2),tris(:,3),'LineStyle','none', ...
        'Cdata',map,'FaceColor','interp')
campos([2 .5 2]);
camtarget([0 0 0]);
axis on;
box on;
grid on;
alpha(.5);
end

C = [1 0 1; 0 1 1; -1 -1 1];
X2=(C^(-1)*X')';
axis off
grid off
hold on;
campos([2 2 2]);
camtarget([0 0 0]);
plot3(X(:,1),X(:,2),X(:,3),'.','MarkerSize',4,'MarkerEdgeColor',mcolor);